coda.pack-package: coda.pack: Meta-Package for Compositional Data Analysis

coda.pack-packageR Documentation

coda.pack: Meta-Package for Compositional Data Analysis

Description

coda.pack is a meta-package for compositional data analysis. It attaches the main stable packages of the coda ecosystem.

Details

The following packages are attached by default:

  • coda.base

  • coda.plot

Development extensions can be installed with install_coda_dev().

Value

No return value, called for its side effects of attaching the package and its imports.

Author(s)

Maintainer: Marc Comas-Cufí mcomas@imae.udg.edu (ORCID)

Examples

library(coda.pack)


coda.pack documentation built on April 19, 2026, 5:07 p.m.