coda_packages: List packages in the coda ecosystem

View source: R/load_coda.pack.R

coda_packagesR Documentation

List packages in the coda ecosystem

Description

Returns a data frame with the packages currently considered part of the coda ecosystem and their installation source.

Usage

coda_packages()

Value

A data frame with one row per package and two columns:

package

Package name.

source

Source from which the package can be installed, currently either "CRAN" or "GitHub".

The returned object is of class data.frame.

Examples

coda_packages()


coda.pack documentation built on April 19, 2026, 5:07 p.m.