View source: R/load_coda.pack.R
| coda_packages | R Documentation |
Returns a data frame with the packages currently considered part of the
coda ecosystem and their installation source.
coda_packages()
A data frame with one row per package and two columns:
Package name.
Source from which the package can be installed, currently
either "CRAN" or "GitHub".
The returned object is of class data.frame.
coda_packages()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.